from .budget import BudgetAdminWidget
from .dashboard import FinancesDashboardWidget
from .costcenter.costcenter_list import CostCenterListApp
from .costcenter.expensecode_list import ExpenseCodeListApp
from .costcenter.financeproject_list import FinanceProjectListApp
from .grant_domain_app import GrantDomainAdminApp

from .financing_agency_app import FinancingAgencyAdminApp

from .grant_app import GrantsAdminApp

